@@ -87,11 +87,8 @@ class FakeMemoFile(object):
 _FAKE_MEMOFILE = FakeMemoFile()
 
 
-class Table(list):
-    """
-    Class to read DBF files.
-    """
-
+class DBF(object):
+    """DBF table."""
     def __init__(self, filename,
                  encoding=None,
                  ignorecase=True,
@@ -111,9 +108,8 @@ class Table(list):
         # Name part before .dbf is the table name
         self.name = os.path.basename(filename)
         self.name = os.path.splitext(self.name)[0].lower()
-        
+        self._records = None
         self._deleted = None
-        self.loaded = False
 
         if ignorecase:
             self.filename = ifind(filename)
@@ -142,28 +138,26 @@ class Table(list):
 
         if load:
             self.load()
-        else:
-            self.unload()
 
-    def _get_memofile(self):
-        if self.memofilename and not self.raw:
-            return FPT(self.memofilename)
-        else:
-            return _FAKE_MEMOFILE
+    @property
+    def loaded(self):
+        return self._records is not None
 
     def load(self):
         if not self.loaded:
-            self[:] = self._iter_records(b' ')
+            self._records = list(self._iter_records(b' '))
             self._deleted = list(self._iter_records(b'*'))
-            self.loaded = True
 
     def unload(self):
-        # self.loaded is not checked here because this
-        # is called by __init__() where self.loaded=False.
-        # Also, unloading twice has no consequences.
-        del self[:]
+        self._records = None
         self._deleted = None
-        self.loaded = False
+
+    @property
+    def records(self):
+        if self.loaded:
+            return self._records
+        else:
+            return RecordIterator(self, b' ')
 
     @property
     def deleted(self):
@@ -172,6 +166,12 @@ class Table(list):
         else:
             return RecordIterator(self, b'*')
 
+    def _get_memofile(self):
+        if self.memofilename and not self.raw:
+            return FPT(self.memofilename)
+        else:
+            return _FAKE_MEMOFILE
+
     def _read_headers(self, infile):
         #
         # Todo: more checks
@@ -183,7 +183,7 @@ class Table(list):
             try:
                 self.encoding = guess_encoding(self.header.language_driver)
             except LookupError as err:
-                self.encoding = 'latin1'
+                self.encoding = 'ascii'
 
         #
         # Read field headers
@@ -194,7 +194,10 @@ class Table(list):
                 # End of field headers
                 break
 
-            fh = DBFField.read(infile, prepend=sep)
+            # sep is the first byte of the field name.
+            # Go back one byte and read field header.
+            infile.seek(-1, 1)
+            fh = DBFField.read(infile)
 
             fieldname = parse_string(fh.name, self.encoding)
             if self.lowernames:
@@ -321,6 +324,51 @@ class Table(list):
                 else:
                     skip_record(infile)
 
+    def __iter__(self):
+        if self.loaded:
+            return list.__iter__(self._records)
+        else:
+            return self._iter_records()
+
+    def __len__(self):
+        return len(self.records)
+
+    def __repr__(self):
+        if self.loaded:
+            status = 'loaded'
+        else:
+            status = 'unloaded'
+        return '<{} DBF table {!r}>'.format(status, self.filename)
+
+    def __enter__(self):
+        return self
+
+    def __exit__(self, type, value, traceback):
+        self.unload()
+        return False
+
+class DeprecatedDBF(DBF, list):
+    """This is the old version of the table which is a subclass of list.
+
+    It is included for backwards compatability with 1.0 and older."""
+    @property
+    def loaded(self):
+        # Since records are loaded into the table object
+        # we have to check the deleted attribute here.
+        return isinstance(self._deleted, list)
+
+    def load(self):
+        if not self.loaded:
+            self[:] = self._iter_records(b' ')
+            self._deleted = list(self._iter_records(b'*'))
+
+    def unload(self):
+        # self.loaded is not checked here because this
+        # is called by __init__() where self.loaded=False.
+        # Also, unloading twice has no consequences.
+        del self[:]
+        self._deleted = None
+        
     def __iter__(self):
         if self.loaded:
             return list.__iter__(self)
@@ -337,4 +385,4 @@ class Table(list):
         if self.loaded:
             return list.__repr__(self)
         else:
-            return '<Unloaded DBF table {!r}>'.format(self.filename)
+            return '<unloaded DBF table {!r}>'.format(self.filename)
