@@ -14,7 +14,7 @@ import dbfread
 db = dataset.connect('sqlite:///:memory:')
 
 table = db['people']
-for record in dbfread.open('people.dbf', lowernames=True,
+for record in dbfread.open('files/people.dbf', lowernames=True,
                            recfactory=collections.OrderedDict):
     table.insert(record)
 
