@@ -41,15 +41,18 @@ def make_field_parser(field_type):
 
 class TestReadAndLength(TestCase):
     def test_all(self):
-        table = dbfread.open('examples/people.dbf')
+        table = dbfread.open('testcases/memotest.dbf')
 
         # This relies on people.dbf having this exact content.
         records = [{u'NAME': u'Alice',
-                    u'BIRTHDATE': datetime.date(1987, 3, 1)},
+                    u'BIRTHDATE': datetime.date(1987, 3, 1),
+                    u'MEMO': u'Alice memo'},
                    {u'NAME': u'Bob',
-                    u'BIRTHDATE': datetime.date(1980, 11, 12)}]
+                    u'BIRTHDATE': datetime.date(1980, 11, 12),
+                    u'MEMO': u'Bob memo'}]
         deleted_records = [{u'NAME': u'Deleted Guy',
-                            u'BIRTHDATE': datetime.date(1979, 12, 22)}]
+                            u'BIRTHDATE': datetime.date(1979, 12, 22),
+                            u'MEMO': u'Deleted Guy memo'}]
 
         assert len(table) == 2
         assert len(table.deleted) == 1
@@ -63,6 +66,9 @@ class TestReadAndLength(TestCase):
         assert list(loaded_table) == records
         assert list(loaded_table.deleted) == deleted_records
 
+        # This should not return old style table which was a subclass of list.
+        assert not isinstance(table, list)
+
 class TestFieldParsers(TestCase):
     def test_0(self):
         parse = make_field_parser('0')
